/**************************************************************************
  CLASS:			MiscIconWell
  INHERITS FROM:	MiscDragView
  PROGRAMMERS:		Todd Thomas			(todd@avocado.supernet.ab.ca)
  					Bruce McKenzie		(spuds@netcom.com)
					Stephen Fitzpatrick (sfitzp@elegabalus.cs.qub.ac.uk)
  BEGAN:			May 24, 1994
  LAST CHANGED:		October 24, 1996
  VERSION:			1.5
  CHANGES:			See the end of MiscIconWell.m.
 
 
  This class (by default) allows both source and destination dragging of 
  icon representations of files and folders and uses the NXFilenamePboardType
  to pass the filename that is associated with the dragged icon.
  Since we are inheriting the basic functionality from MiscDragView, we 
  should not need to do much. 
 
  This object is included in the MiscKit by permission from the author
  and its use is governed by the MiscKit license, found in the file
  "LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
  for a list of all applicable permissions and restrictions.
 
 * Copyright (C) 1995 Robert Todd Thomas
 * Use is governed by the MiscKit license
 ***************************************************************************/
 
#import <appkit/appkit.h>
#import <misckit/MiscDragView.h>


@interface MiscIconWell : MiscDragView
{
	char  *filename;	// to char* for easier palette loading in IB 
	const char *defaultName;
	const char *types;		
	BOOL  allowDoubleClickLaunch;
	BOOL	allowMFDragging;
}

- initFrame: (const NXRect *)frameRect;
- initDragTypes;
- free;

- (const char *)filename;
- setImage: (NXImage *)anImage;
- setImageByFilename: (const char *)aFilename;
- setAllowDoubleClickLaunch: (BOOL)aBool;
- (BOOL)allowDoubleClickLaunch;
- (BOOL)allowMFDragging;
- (void)setAllowMFDragging:(BOOL)anAllowMFDragging;

// Launch/open file in WS: BJM 5/24/94
- launch:sender;

- mouseDown: (NXEvent *)theEvent;
- (BOOL)setupForSourceDrag;
- (BOOL)performDragOperation: sender;
- concludeDragOperation: sender;

- read: (NXTypedStream *)stream;
- write: (NXTypedStream *)stream;

- (const char *)defaultName;
- (void)setDefaultName:(const char *)aDefaultName;

- (const char *)fileTypes;
- (void)setFileTypes:(const char *)aTypes;

- doSetDefaultName;

@end
